@@ -1,4 +1,6 @@
 /*
+ * Copyright 2013-2021 Charles Oliver Nutter <headius@headius.com>
+ *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
@@ -18,8 +20,8 @@ package com.headius.options;
  * An Enum-based Option.
  */
 public class EnumerationOption<T extends Enum<T>> extends Option<T> {
-    public EnumerationOption(String prefix, String name, Enum category, Class<T> enumType, T defval, String description) {
-        super(prefix, name, enumType, category, (T[])enumType.getEnumConstants(), defval, description);
+    public EnumerationOption(String prefix, String shortName, Enum category, Class<T> enumType, T defval, String description) {
+        super(prefix, shortName, enumType, category, (T[])enumType.getEnumConstants(), defval, description);
     }
     
     public EnumerationOption(String longName, Enum category, Class<T> enumType, T defval, String description) {
