@@ -1,4 +1,6 @@
-/*
+/**
+ * Copyright 2013-2021 Charles Oliver Nutter <headius@headius.com>
+ *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
@@ -42,7 +44,6 @@ public abstract class Option<T> {
     /**
      * Create a new option with the given values.
      * 
-     * @param <C> an enumeration type
      * @param prefix the prefix used for loading this option from properties
      * @param shortName the rest of the property name
      * @param type the value type of the option
@@ -68,7 +69,6 @@ public abstract class Option<T> {
     /**
      * Create a new option with the given values.
      * 
-     * @param <C> an enumeration type
      * @param longName the property name
      * @param type the value type of the option
      * @param category the category to which this option belongs
@@ -92,13 +92,27 @@ public abstract class Option<T> {
     
     /**
      * Create a new String option with the given configuration.
+     *
+     * @param prefix the prefix used for loading this option from properties
+     * @param shortName the rest of the property name
+     * @param category the category to which this option belongs
+     * @param description a description for the option
+     *
+     * @return a new String-based option
      */
-    public static Option<String> string(String prefix, String name, Enum category, String description) {
-        return new StringOption(prefix, name, category, null, null, description);
+    public static Option<String> string(String prefix, String shortName, Enum category, String description) {
+        return new StringOption(prefix, shortName, category, null, null, description);
     }
-    
+
+
     /**
      * Create a new String option with the given configuration.
+     *
+     * @param longName the property name
+     * @param category the category to which this option belongs
+     * @param description a description for the option
+     *
+     * @return a new String-based option
      */
     public static Option<String> string(String longName, Enum category, String description) {
         return new StringOption(longName, category, null, null, description);
@@ -106,13 +120,28 @@ public abstract class Option<T> {
     
     /**
      * Create a new String option with the given configuration.
+     *
+     * @param prefix the prefix used for loading this option from properties
+     * @param shortName the rest of the property name
+     * @param category the category to which this option belongs
+     * @param defval the default value for the option
+     * @param description a description for the option
+     *
+     * @return a new String-based Option
      */
-    public static Option<String> string(String prefix, String name, Enum category, String defval, String description) {
-        return new StringOption(prefix, name, category, null, defval, description);
+    public static Option<String> string(String prefix, String shortName, Enum category, String defval, String description) {
+        return new StringOption(prefix, shortName, category, null, defval, description);
     }
     
     /**
      * Create a new String option with the given configuration.
+     *
+     * @param longName the property name
+     * @param category the category to which this option belongs
+     * @param defval the default value for the option
+     * @param description a description for the option
+     *
+     * @return a new String-based Option
      */
     public static Option<String> string(String longName, Enum category, String defval, String description) {
         return new StringOption(longName, category, null, defval, description);
@@ -120,13 +149,30 @@ public abstract class Option<T> {
     
     /**
      * Create a new String option with the given configuration.
+     *
+     * @param prefix the prefix used for loading this option from properties
+     * @param shortName the rest of the property name
+     * @param category the category to which this option belongs
+     * @param options a list of supported for the option, or null if the set is
+     *                not applicable
+     * @param description a description for the option
+     *
+     * @return a new String-based Option
      */
-    public static Option<String> string(String prefix, String name, Enum category, String[] options, String description) {
-        return new StringOption(prefix, name, category, options, null, description);
+    public static Option<String> string(String prefix, String shortName, Enum category, String[] options, String description) {
+        return new StringOption(prefix, shortName, category, options, null, description);
     }
     
     /**
      * Create a new String option with the given configuration.
+     *
+     * @param longName the property name
+     * @param category the category to which this option belongs
+     * @param options a list of supported for the option, or null if the set is
+     *                not applicable
+     * @param description a description for the option
+     *
+     * @return a new String-based Option
      */
     public static Option<String> string(String longName, Enum category, String[] options, String description) {
         return new StringOption(longName, category, options, null, description);
@@ -134,13 +180,32 @@ public abstract class Option<T> {
     
     /**
      * Create a new String option with the given configuration.
+     *
+     * @param prefix the prefix used for loading this option from properties
+     * @param shortName the rest of the property name
+     * @param category the category to which this option belongs
+     * @param options a list of supported for the option, or null if the set is
+     *                not applicable
+     * @param defval the default value for the option
+     * @param description a description for the option
+     *
+     * @return a new String-based Option
      */
-    public static Option<String> string(String prefix, String name, Enum category, String[] options, String defval, String description) {
-        return new StringOption(prefix, name, category, options, defval, description);
+    public static Option<String> string(String prefix, String shortName, Enum category, String[] options, String defval, String description) {
+        return new StringOption(prefix, shortName, category, options, defval, description);
     }
     
     /**
      * Create a new String option with the given configuration.
+     *
+     * @param longName the property name
+     * @param category the category to which this option belongs
+     * @param options a list of supported for the option, or null if the set is
+     *                not applicable
+     * @param defval the default value for the option
+     * @param description a description for the option
+     *
+     * @return a new String-based Option
      */
     public static Option<String> string(String longName, Enum category, String[] options, String defval, String description) {
         return new StringOption(longName, category, options, defval, description);
@@ -148,13 +213,26 @@ public abstract class Option<T> {
     
     /**
      * Create a new Boolean option with the given configuration.
+     *
+     * @param prefix the prefix used for loading this option from properties
+     * @param shortName the rest of the property name
+     * @param category the category to which this option belongs
+     * @param description a description for the option
+     *
+     * @return a new Boolean-based Option
      */
-    public static Option<Boolean> bool(String prefix, String name, Enum category, String description) {
-        return new BooleanOption(prefix, name, category, null, description);
+    public static Option<Boolean> bool(String prefix, String shortName, Enum category, String description) {
+        return new BooleanOption(prefix, shortName, category, null, description);
     }
     
     /**
      * Create a new Boolean option with the given configuration.
+     *
+     * @param longName the property name
+     * @param category the category to which this option belongs
+     * @param description a description for the option
+     *
+     * @return a new Boolean-based Option
      */
     public static Option<Boolean> bool(String longName, Enum category, String description) {
         return new BooleanOption(longName, category, null, description);
@@ -162,13 +240,28 @@ public abstract class Option<T> {
     
     /**
      * Create a new Boolean option with the given configuration.
+     *
+     * @param prefix the prefix used for loading this option from properties
+     * @param shortName the rest of the property name
+     * @param category the category to which this option belongs
+     * @param defval the default value for the option
+     * @param description a description for the option
+     *
+     * @return a new Boolean-based Option
      */
-    public static Option<Boolean> bool(String prefix, String name, Enum category, Boolean defval, String description) {
-        return new BooleanOption(prefix, name, category, defval, description);
+    public static Option<Boolean> bool(String prefix, String shortName, Enum category, Boolean defval, String description) {
+        return new BooleanOption(prefix, shortName, category, defval, description);
     }
     
     /**
      * Create a new Boolean option with the given configuration.
+     *
+     * @param longName the property name
+     * @param category the category to which this option belongs
+     * @param defval the default value for the option
+     * @param description a description for the option
+     *
+     * @return a new Boolean-based Option
      */
     public static Option<Boolean> bool(String longName, Enum category, Boolean defval, String description) {
         return new BooleanOption(longName, category, defval, description);
@@ -176,20 +269,42 @@ public abstract class Option<T> {
     
     /**
      * Create a new Integer option with the given configuration.
+     *
+     * @param prefix the prefix used for loading this option from properties
+     * @param shortName the rest of the property name
+     * @param category the category to which this option belongs
+     * @param description a description for the option
+     *
+     * @return a new Integer-based Option
      */
-    public static Option<Integer> integer(String prefix, String name, Enum category, String description) {
-        return new IntegerOption(prefix, name, category, null, description);
+    public static Option<Integer> integer(String prefix, String shortName, Enum category, String description) {
+        return new IntegerOption(prefix, shortName, category, null, description);
     }
     
     /**
      * Create a new Integer option with the given configuration.
+     *
+     * @param prefix the prefix used for loading this option from properties
+     * @param shortName the rest of the property name
+     * @param category the category to which this option belongs
+     * @param options a list of supported for the option, or null if the set is
+     *                not applicable
+     * @param description a description for the option
+     *
+     * @return a new Integer-based Option
      */
-    public static Option<Integer> integer(String prefix, String name, Enum category, Integer[] options, String description) {
-        return new IntegerOption(prefix, name, category, options, null, description);
+    public static Option<Integer> integer(String prefix, String shortName, Enum category, Integer[] options, String description) {
+        return new IntegerOption(prefix, shortName, category, options, null, description);
     }
     
     /**
      * Create a new Integer option with the given configuration.
+     *
+     * @param longName the property name
+     * @param category the category to which this option belongs
+     * @param description a description for the option
+     *
+     * @return a new Integer-based Option
      */
     public static Option<Integer> integer(String longName, Enum category, String description) {
         return new IntegerOption(longName, category, null, description);
@@ -197,6 +312,14 @@ public abstract class Option<T> {
     
     /**
      * Create a new Integer option with the given configuration.
+     *
+     * @param longName the property name
+     * @param category the category to which this option belongs
+     * @param options a list of supported for the option, or null if the set is
+     *                not applicable
+     * @param description a description for the option
+     *
+     * @return a new Integer-based Option
      */
     public static Option<Integer> integer(String longName, Enum category, Integer[] options, String description) {
         return new IntegerOption(longName, category, options, null, description);
@@ -204,13 +327,28 @@ public abstract class Option<T> {
     
     /**
      * Create a new Integer option with the given configuration.
+     *
+     * @param prefix the prefix used for loading this option from properties
+     * @param shortName the rest of the property name
+     * @param category the category to which this option belongs
+     * @param defval the default value for the option
+     * @param description a description for the option
+     *
+     * @return a new Integer-based Option
      */
-    public static Option<Integer> integer(String prefix, String name, Enum category, Integer defval, String description) {
-        return new IntegerOption(prefix, name, category, defval, description);
+    public static Option<Integer> integer(String prefix, String shortName, Enum category, Integer defval, String description) {
+        return new IntegerOption(prefix, shortName, category, defval, description);
     }
     
     /**
      * Create a new Integer option with the given configuration.
+     *
+     * @param longName the property name
+     * @param category the category to which this option belongs
+     * @param defval the default value for the option
+     * @param description a description for the option
+     *
+     * @return a new Integer-based Option
      */
     public static Option<Integer> integer(String longName, Enum category, Integer defval, String description) {
         return new IntegerOption(longName, category, defval, description);
@@ -218,13 +356,32 @@ public abstract class Option<T> {
     
     /**
      * Create a new Integer option with the given configuration.
+     *
+     * @param prefix the prefix used for loading this option from properties
+     * @param shortName the rest of the property name
+     * @param category the category to which this option belongs
+     * @param options a list of supported for the option, or null if the set is
+     *                not applicable
+     * @param defval the default value for the option
+     * @param description a description for the option
+     *
+     * @return a new Integer-based Option
      */
-    public static Option<Integer> integer(String prefix, String name, Enum category, Integer[] options, Integer defval, String description) {
-        return new IntegerOption(prefix, name, category, options, defval, description);
+    public static Option<Integer> integer(String prefix, String shortName, Enum category, Integer[] options, Integer defval, String description) {
+        return new IntegerOption(prefix, shortName, category, options, defval, description);
     }
     
     /**
      * Create a new Integer option with the given configuration.
+     *
+     * @param longName the property name
+     * @param category the category to which this option belongs
+     * @param options a list of supported for the option, or null if the set is
+     *                not applicable
+     * @param defval the default value for the option
+     * @param description a description for the option
+     *
+     * @return a new Integer-based Option
      */
     public static Option<Integer> integer(String longName, Enum category, Integer[] options, Integer defval, String description) {
         return new IntegerOption(longName, category, options, defval, description);
@@ -232,13 +389,28 @@ public abstract class Option<T> {
     
     /**
      * Create a new Enumeration-based option with the given configuration.
+     *
+     * @param <T> the type of the enum
+     * @param prefix the prefix used for loading this option from properties
+     * @param shortName the rest of the property name
+     * @param category the category to which this option belongs
+     * @param description a description for the option
+     *
+     * @return a new Enumeration-based Option
      */
-    public static <T extends Enum<T>> Option<T> enumeration(String prefix, String name, Enum category, Class<T> enumClass, String description) {
-        return new EnumerationOption(prefix, name, category, enumClass, null, description);
+    public static <T extends Enum<T>> Option<T> enumeration(String prefix, String shortName, Enum category, Class<T> enumClass, String description) {
+        return new EnumerationOption(prefix, shortName, category, enumClass, null, description);
     }
     
     /**
      * Create a new Enumeration-based option with the given configuration.
+     *
+     * @param <T> the type of the enum
+     * @param longName the property name
+     * @param category the category to which this option belongs
+     * @param description a description for the option
+     *
+     * @return a new Enumeration-based Option
      */
     public static <T extends Enum<T>> Option<T> enumeration(String longName, Enum category, Class<T> enumClass, String description) {
         return new EnumerationOption(longName, category, enumClass, null, description);
@@ -246,13 +418,30 @@ public abstract class Option<T> {
     
     /**
      * Create a new Enumeration-based option with the given configuration.
+     *
+     * @param <T> the type of the enum
+     * @param prefix the prefix used for loading this option from properties
+     * @param shortName the rest of the property name
+     * @param category the category to which this option belongs
+     * @param defval the default value for the option
+     * @param description a description for the option
+     *
+     * @return a new Enumeration-based Option
      */
-    public static <T extends Enum<T>> Option<T> enumeration(String prefix, String name, Enum category, T defval, String description) {
-        return new EnumerationOption(prefix, name, category, defval.getClass(), defval, description);
+    public static <T extends Enum<T>> Option<T> enumeration(String prefix, String shortName, Enum category, T defval, String description) {
+        return new EnumerationOption(prefix, shortName, category, defval.getClass(), defval, description);
     }
     
     /**
      * Create a new Enumeration-based option with the given configuration.
+     *
+     * @param <T> the type of the enum
+     * @param longName the property name
+     * @param category the category to which this option belongs
+     * @param defval the default value for the option
+     * @param description a description for the option
+     *
+     * @return a new Enumeration-based Option
      */
     public static <T extends Enum<T>> Option<T> enumeration(String longName, Enum category, T defval, String description) {
         return new EnumerationOption(longName, category, defval.getClass(), defval, description);
@@ -260,6 +449,9 @@ public abstract class Option<T> {
     
     /**
      * Format the given options to show their loaded values in the current JVM.
+     *
+     * @param options the options to format
+     * @return a formatted string representing the options
      */
     public static String formatValues(Option... options) {
         return formatValues(Arrays.asList(options));
@@ -267,6 +459,9 @@ public abstract class Option<T> {
     
     /**
      * Format the given options to show their loaded values in the current JVM.
+     *
+     * @param options the options to format
+     * @return a formatted string representing the options
      */
     public static String formatValues(Collection<Option> options) {
         StringBuilder sb = new StringBuilder();
@@ -296,6 +491,9 @@ public abstract class Option<T> {
     /**
      * Format the given options in a way suitable for use as a configuration
      * file or documentation.
+     *
+     * @param options the options to format
+     * @return a formatted string representing the options as a config file or document
      */
     public static String formatOptions(Option... options) {
         return formatOptions(Arrays.asList(options));
@@ -304,6 +502,9 @@ public abstract class Option<T> {
     /**
      * Format the given options in a way suitable for use as a configuration
      * file or documentation.
+     *
+     * @param options the options to format
+     * @return a formatted string representing the options as a config file or document
      */
     public static String formatOptions(Collection<Option> options) {
         StringBuilder sb = new StringBuilder();
@@ -393,6 +594,9 @@ public abstract class Option<T> {
 
     /**
      * Load the option's property, as if by calling java.lang.System#getProperty
+     *
+     * @return the option's property's current value, or a value previously forced
+     * into this option by {@link #force(String)}
      */
     public synchronized String loadProperty() {
         String value = forced;
@@ -409,14 +613,14 @@ public abstract class Option<T> {
     }
 
     /**
-     * Return true if the option's property was specified, false otherwise.
+     * @return true if the option's property was specified, false otherwise.
      */
     public boolean isSpecified() {
         return specified;
     }
 
     /**
-     * Return the value of the option, loading if it has not been already.
+     * @return the value of the option, loading if it has not been already.
      */
     public final T load() {
         if (loaded) return value;
@@ -426,6 +630,8 @@ public abstract class Option<T> {
     
     /**
      * Force a load of the option's property and return the loaded value.
+     *
+     * @return the loaded value
      */
     public final synchronized T reload() {
         if (loaded) return value;
@@ -438,7 +644,8 @@ public abstract class Option<T> {
 
     /**
      * Force the property value to the given value for all future loads and reloads.
-     * @param value
+     *
+     * @param value a value to force for the Option's property, as if set in JVM
      */
     public synchronized void force(String value) {
         forced = value;
@@ -457,18 +664,22 @@ public abstract class Option<T> {
     
     /**
      * Perform the appropriate load and conversion for the option's property.
+     *
+     * @return the updated value after reload
      */
     protected abstract T reloadValue();
     
     /**
      * If the option has a short name, return it. Otherwise null.
+     *
+     * @return the short name, or else null
      */
     public String shortName() {
         return shortName;
     }
     
     /**
-     * Return the full property name for the option.
+     * @return the full property name for the option.
      */
     public String propertyName() {
         return longName;
@@ -476,6 +687,8 @@ public abstract class Option<T> {
     
     /**
      * If the property has a prefix, return it. Otherwise null.
+     *
+     * @return the property prefix, or else null
      */
     public String prefix() {
         return prefix;
@@ -483,6 +696,8 @@ public abstract class Option<T> {
     
     /**
      * The display name of the option's property, either the short name or the full name.
+     *
+     * @return the full display name of this option's property
      */
     public String displayName() {
         return displayName;
@@ -490,7 +705,8 @@ public abstract class Option<T> {
     
     /**
      * The type returned for the option.
-     * @return 
+     *
+     * @return the type of option that this is
      */
     public Class<T> type() {
         return type;
@@ -498,20 +714,22 @@ public abstract class Option<T> {
     
     /**
      * The array of accepted values for the option, or null if any values are accepted.
+     *
+     * @return an array of accepted values, or null if any values are allowed
      */
     public T[] options() {
         return options == null ? null : options.clone();
     }
     
     /**
-     * The default value for the option, or null if no default is provided.
+     * @return the default value for the option, or null if no default is provided.
      */
     public T defaultValue() {
         return defval;
     }
     
     /**
-     * The long description of the property, as for documentation and configuration file templates.
+     * @return the long description of the property, as for documentation and configuration file templates.
      */
     public String description() {
         return description;
