@@ -1,4 +1,6 @@
 /*
+ * Copyright 2013-2021 Charles Oliver Nutter <headius@headius.com>
+ *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
@@ -18,8 +20,8 @@ package com.headius.options;
  * A String-based Option.
  */
 public class StringOption extends Option<String> {
-    public StringOption(String prefix, String name, Enum category, String[] options, String defval, String description) {
-        super(prefix, name, String.class, category, options, defval, description);
+    public StringOption(String prefix, String shortName, Enum category, String[] options, String defval, String description) {
+        super(prefix, shortName, String.class, category, options, defval, description);
     }
     
     public StringOption(String longName, Enum category, String[] options, String defval, String description) {
